<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;
use Teknisa\Libs\Util\Environment;

class ManutencaoCampanhaFidelidade extends \Zeedhi\Framework\Controller\Simple {

	protected $manuCampFidelService;
	protected $util;
	protected $environment;


	public function __construct(Services\ManutencaoCampanhaFidelidade $manuCampFidelService, Utilities\Util $util, Environment $environment) {
		$this->manuCampFidelService 	 = $manuCampFidelService;
		$this->util                      = $util;
		$this->environment               = $environment;
		
	}

    public function findCampFidelidade(Request\Filter $request, Response $response) {
        $row = $this->util->getParamsAsArray($request);
        $data = $this->manuCampFidelService->findCampFidelidade($row);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('vnd10150_manutcampfide', $data));
    }

    public function findCampByFilial(Request\Filter $request, Response $response) {
        $row = $request->getFilterCriteria()->getConditions();
        $data = $this->manuCampFidelService->findCampByFilial($row);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('vnd10150_manutcampfide_getCampByFilial', $data));
    }
    
    public function findSaldoAtual(Request\Filter $request, Response $response) {
        $row = $request->getFilterCriteria()->getConditions();
        $data = $this->manuCampFidelService->findSaldoAtual($row);

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('data', $data));
    }
    
    public function saveCampFidelidade(Request\DataSet $request, Response $response){
	    try {
    	    $dataSet = $request->getDataSet();
            $rows = $dataSet->getRows();
            
            $currentTime = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
            foreach ($rows as $row) {
                if (is_object($row))
                $row = (array) $row;
                $row['NRORG'] = $this->environment->getNrOrgTrab();
                $row['DTULTATU'] = $row['DTINCLUSAO'];
                $row['CDOPERINCLUSAO'] = $this->environment->getCdOperador();
                if($row['IDTPMOVCONS'] == 'C'){
                    $row['VRSALDOCONS'] = $row['VRMOVPONTOCONS'];
                }else{
                    $row['VRSALDOCONS'] = null;
                }
                
                if(isset($row['__is_new']) && $row['__is_new'] == true) {
                    $this->manuCampFidelService->saveCampFidelidade($row);
                } else {
                    $this->manuCampFidelService->updateCampFidelidade($row);
                }
                
                $response->addNotification(new Notification("Dados salvos com sucesso!"), Notification::TYPE_SUCCESS);
            }
	    } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
	}
	
	public function findOperador(Request\Filter $request, Response $response) {
        $cdoperador = $this->environment->getCdOperador();
        $operador = $this->manuCampFidelService->findOperador($cdoperador);

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('vnd10150_manutcampfide_operador', $operador));
    }
    
    public function findVoucher(Request\Filter $request, Response $response) {
        $row = $request->getFilterCriteria()->getConditions();

        $data = $this->manuCampFidelService->findVoucher($row);

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('vnd10150_manutcampfide_voucher', $data));
    }
    
    public function verifyExistVoucher(Request\Filter $request, Response $response) {
        $row = $request->getFilterCriteria()->getConditions();

        $data = $this->manuCampFidelService->verifyExistVoucher($row);

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('vnd10150_manutcampfide_voucherValid', $data));
    }

    public function getCodManut(Request\Filter $request, Response $response) {
        $row = $request->getFilterCriteria()->getConditions();
        
        $data = $this->manuCampFidelService->getCodManut($row);
        
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('vnd10150_manutcampfide_codManut', $data));
    }
}